import { styled } from '@mui/material/styles';
import Avatar from '@mui/material/Avatar';
import MuiDrawer, { drawerClasses } from '@mui/material/Drawer';
import Box from '@mui/material/Box';
import Stack from '@mui/material/Stack';
import Typography from '@mui/material/Typography';
import MenuContent from '../MenuContent';
import OptionsMenu from '../OptionsMenu';
import React from 'react';
import { ArrowLeftIcon, ArrowRightIcon } from '@mui/x-date-pickers';
import { Button } from '@mui/material';

const drawerWidth = 240;

const Drawer = styled(MuiDrawer)({
  width: drawerWidth,
  flexShrink: 0,
  boxSizing: 'border-box',
  mt: 10,
  [`& .${drawerClasses.paper}`]: {
    width: drawerWidth,
    boxSizing: 'border-box',
  },
});

export default function SideMenu() {
  const [open, setOpen] = React.useState(true);
  return (
    <Drawer
      open={open}
      variant="permanent"
      anchor="left"
      sx={{
        display: {
          xs: 'none',
          md: 'block',
          width: open ? 220 : 80,
          transition: 'all 0.5s ease',
        },
        [`& .${drawerClasses.paper}`]: {
          backgroundColor: 'background.paper',
          width: open ? 220 : 80,
          transition: 'all 0.5s ease',
        },
      }}
    >
      <Box
        sx={{
          display: 'flex',
          justifyContent: open ? 'flex-end' : 'center',
          alignItems: 'center',
          pt: 1.5,
          textAlign: 'center',
        }}
      >
        <Button variant="text" onClick={() => setOpen(!open)}>
          {open ? <ArrowLeftIcon /> : <ArrowRightIcon />}
        </Button>
      </Box>
      <MenuContent hidden={open} />
      {/* <CardAlert /> */}
      <Stack
        direction="row"
        sx={{
          p: 2,
          gap: 1,
          alignItems: 'center',
          borderTop: '1px solid',
          borderColor: 'divider',
        }}
      >
        <Avatar
          sizes="small"
          alt="Riley Carter"
          src="/static/images/avatar/7.jpg"
          sx={{ width: open ? 36 : 0, height: open ? 36 : 0 }}
        />
        <Box sx={{ mr: 'auto', display: !open ? 'none' : 'block' }}>
          <Typography
            variant="body2"
            sx={{ fontWeight: 500, lineHeight: '16px' }}
          >
            Riley Carter
          </Typography>
          <Typography variant="caption" sx={{ color: 'text.secondary' }}>
            riley@email.com
          </Typography>
        </Box>
        <OptionsMenu avatar={open} />
      </Stack>
    </Drawer>
  );
}
