import { Routes as BaseRoutes, Navigate, Route } from "react-router-dom"
// import useAuth from "./hooks/useAuth";
import React, { Suspense } from "react"
import LoadingComponent from "./components/Loading"
import DashboardLayout from "./layouts/DashboardLayout"
import Login from "./pages/Auth/Login"
import SignUp from "./pages/Auth/SignUp"
import Dashboard from "./pages/Dashboard"
import Vehicles from "./pages/Vechiles"
import AdminList from "./pages/AdminList"

function ProtectedRoute({
    caps,
    component,
}: {
    caps: string[]
    component: React.ReactNode
}) {
    if (!localStorage.getItem("authToken"))
        return <Navigate to={`/auth/login`} replace />

    return component
}

export default function AppRouter() {
    return (
        <Suspense fallback={<LoadingComponent />}>
            <BaseRoutes>
                <Route element={<Navigate to="/auth/login" replace />} index />

                <Route path="/auth">
                    <Route
                        path=""
                        element={<Navigate to="/auth/login" replace />}
                        index
                    />
                    <Route path="login" element={<Login />} />
                    <Route path="signup" element={<SignUp />} />
                </Route>
                <Route path="/panel" element={<DashboardLayout />}>
                    <Route
                        path="dashboard"
                        element={
                            <ProtectedRoute
                                caps={[]}
                                component={<Dashboard />}
                            />
                        }
                    />
                    <Route
                        path="vehicles"
                        element={
                            <ProtectedRoute
                                caps={[]}
                                component={<Vehicles />}
                            />
                        }
                    />
                    <Route
                        path="adminlist"
                        element={
                            <ProtectedRoute
                                caps={[]}
                                component={<AdminList />}
                            />
                        }
                    />
                    <Route path="*" element={<>404</>} />
                </Route>
                <Route path="*" element={<>404</>} />
            </BaseRoutes>
        </Suspense>
    )
}
